#!/bin/env python

# DECCA infomation:
#
# Copyright (C) 2006 Markus Dickinson, Detmar Meurers, Adriane Boyd
# Contact: decca@ling.osu.edu
# URL: http://decca.osu.edu
# License: GNU GPL (http://decca.osu.edu/software/license.html)

# This script addresses problems with applyng XSLT stylesheets to large
# TigerXML corpus files.  Instead of reading in the entire corpus file,
# it applies an XSL stylesheet to each sentence found in a TigerXML
# file.  It's not very smart, so it depends on the fact that the sentence 
# start and end tags appear on separate lines.

# --------------------------------------------------------

import string
import re
import sys
import libxml2
import libxslt

try:
  xslfile = sys.argv[1]
  xmlfile = sys.argv[2]
except:
  print "Usage: " + sys.argv[0] + " xsl-file tigerxml-file"
  sys.exit()

xmlfileh = open(xmlfile)

sentstart = "<s "
sentend = "</s>"

sentstartpatt = re.compile(sentstart)
sentendpatt = re.compile(sentend)

styledoc = libxml2.parseFile(xslfile)
style = libxslt.parseStylesheetDoc(styledoc)

# read in sentence chunks from tigerxml file and process with xsl
insent = 0
for line in xmlfileh:
  if sentstartpatt.search(line):
    sentence = line
    insent = 1
  elif sentendpatt.search(line):
    sentence += line
    xmldoc = libxml2.parseDoc(sentence)
    result = style.applyStylesheet(xmldoc, None)
    plainresult = style.saveResultToString(result)
    rarray = plainresult.splitlines()
    for line in rarray:
      line = line.strip()
      if line:
        print line
    xmldoc.freeDoc()
    result.freeDoc()
    insent = 0
  elif insent == 1:
    sentence += line

xmlfileh.close()
